Form Helper
===========

Usage
-----

### Form::radio()

This is an extended version of Cake's `radio` method that adds additional markup so that radio buttons are easier to work with. Each input-label pair is wrapped in a `div` that you can set the class of using `wrapInput`; and all the inputs are wrapped in another `div` that you can set the class of using `wrapInputs`.

To set a class on the fieldset's legend you can pass an array containing `class` and `text` (for the legend's text). This is an extension of Cake's usual behaviour but consistent with how it handles `input` labels.

For example:-

	echo $this->Form->radio(
		'colours',
		['red', 'green', 'blue'],
		[
			'legend' => [
				'class' => 'col-xs-12 col-md-4 control-label',
				'text' => 'Select a colour'
			],
			'wrapInput' => 'inline-radio radio',
			'wrapInputs' => 'col-xs-12 col-sm-7'
		]
	);

If you need to remove the legend/fieldset set `legend => false` as you normally would with Cake. Remember for accessibility radio buttons should have a fieldset and legend.

The method uses the `separator` attribute for determining where the split between the inputs is so override this with caution!

Should you need to override the wrapInput on an individual radio options this can be attained by passing through
an array in place of the radio option value for the particular radio option

For example:-

	echo $this->Form->radio(
		'colours',
		[
			[
				'name' => 'red',
				'wrapInput' => 'inline-radio radio radio--red'
			],
			'green',
			'blue'
		],
		[
			'legend' => [
				'class' => 'col-xs-12 col-md-4 control-label',
				'text' => 'Select a colour'
			],
			'wrapInput' => 'inline-radio radio',
			'wrapInputs' => 'col-xs-12 col-sm-7'
		]
	);

### Form::yesOrNo()

This provides a simple select or radio element with the options 'yes' (1/`true`) and 'no' (0/`false`).

	echo $this->Form->yesOrNo('do_you_like_cake');

You can reverse the order of the options by passing `reverseOptions` like this:-

	echo $this->Form->yesOrNo('do_you_like_cake', ['reverseOptions' => true]);

To use as radio inputs pass the `radio` type:-

	echo $this->Form->yesOrNo('do_you_like_cake', ['type' => 'radio']);

### Form::isFieldsError()

Checks whether one or more of the passed field names currently has an active validation error.

	if ($this->Form->isFieldsError(['foo', 'bar'])):
		echo 'Error';
	endif;

This works by calling `isFieldError()` for each of the field names.

###Form::recaptch()

Returns a reCAPTCHA ready form element, using the form input defaults as a basis for the reCAPTCHA element output with the aim of the field laying out seamlessly on the template with further form fields.

* Requires a `data-sitekey` attribute to operate which is supplied by Google when setting up Google reCAPTCHA for the app


Development
-----------

When developing with EvForm please make sure that the unit tests run successfully and add tests for any new features you add. If you find a bug and fix it add a test case to ensure that the bug is resolved and doesn't get broken again.

If you don't know how unit testing works in CakePHP ask!
